import axios from 'axios';
import { Configuration } from './configuration';
import { Session } from './session';
import {
  AirportOverviewBackend,
  AirportOverview,
  BackendReturnStatus,
} from '../types';

export class Airport {
  static async all(): Promise<AirportOverviewBackend> {
    const token = Session.bearerToken();
    if (!token) {
      return {
        status: BackendReturnStatus.Unauthorized,
        airports: [],
      };
    }

    return axios
      .get<AirportOverview[]>(`${Configuration.resourceServer}/airport/all`, {
        headers: {
          Authorization: `Bearer ${token}`,
        },
      })
      .then((response) => {
        return {
          status: BackendReturnStatus.Ok,
          airports: response.data,
        };
      })
      .catch((err) => {
        return {
          status: err.response.status === 401 ? BackendReturnStatus.Unauthorized : BackendReturnStatus.Failure,
          airports: [],
        };
      });
  }
}
